# Step 6: Start the Rationalization Initiative
### On this page
  * [Create Transformations](https://help.sap.com/docs/leanix/ea/application-rationalization-start-initiative#create-transformations)
  * [Start Transformations](https://help.sap.com/docs/leanix/ea/application-rationalization-start-initiative#start-transformations)


Plan and execute IT application changes using the transformations feature.
It’s time to start the rationalization. To keep an overview of your inventory as is but also the future, you use transformations. Designing transformations allows you to model your future IT landscape without changing any current information about your as-is architecture. Once the applications are decommissioned or migrated, etc, with just one click you can update the inventory to reflect the status post-transformation.
By inserting multiple transformations with various completion dates, you can model a layered approach to your Application Rationalization initiative, for example, decommissioning an application country by country.
To learn more about transformations, go to [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US "https://help.sap.com/docs/leanix/ea/transformations?locale=en-US").
